Changelog
=========

Version 0.3.1
-------------

- Fixed bug in 'flush' CLI command


Version 0.3
-----------

- More efficient flushing algorithm, less prone to DB serialization problems


Version 0.2
-----------

- Initial public release
